@@ -201,39 +201,18 @@ impl AminoAcidTranslator {
 pub fn pn2codon(
     file_steem: String,
     gene_table: HashMap<char, Vec<String>>,
-    amino_seqs: Vec<(String, String)>,
-    nuc_seqs: Vec<(String, String)>,
-) -> String {
-    let aa_seq_len = amino_seqs.len();
-    let nt_seq_len = nuc_seqs.len();
-
-    if aa_seq_len != nt_seq_len {
-        let longer_shorter = match aa_seq_len > nt_seq_len {
-            true => ("AA", "NT"),
-            false => ("NT", "AA"),
-        };
-
-        let diff = match aa_seq_len > nt_seq_len {
-            true => ((aa_seq_len as isize) - (aa_seq_len as isize)).abs(),
-            false => ((nt_seq_len as isize) - (aa_seq_len as isize)).abs(),
-        };
-
-        println!(
-            "Length of the {} sequence is longer than the length of {} sequence by a number of {}.",
-            longer_shorter.0, longer_shorter.1, diff
-        );
-
-        return "".to_string();
-    }
-
-    let mut dont_skip = RefCell::new(true);
+    seqs: HashMap<String, ((String, String), (usize, String, String))>
+) -> String {    
+    let mut dont_skip = RefCell::new(true);   
+    let seq_length = seqs.len();
+    let mut ret = vec![Vec::<String>::new(); seq_length];
    
-    let file = String::from_iter(amino_seqs
+    
+
+    seqs
         .iter()
-        .cloned()
-        .zip(nuc_seqs.iter().cloned())
         .take_while(|_| dont_skip.clone().into_inner())
-        .map(|((aa_header, aa), (nt_header, nt))| {
+        .for_each(|(header, ((aa_header, aa), (i, nt_header, nt)))| {
             if !dont_skip.clone().into_inner() {
                 println!("{}", dont_skip.clone().into_inner());
             }
@@ -243,21 +222,20 @@ pub fn pn2codon(
                 (nt_header.clone(), nt.clone()),
                 (dont_skip.clone(), file_steem.clone())
             );
-            amino_acid.do_checks();
             amino_acid.streamline();
+            amino_acid.do_checks();
 
             let mut codon = amino_acid.reverse_translate_and_compare(&gene_table);
-            let mut h_clone = aa_header.clone();
+            let mut h_clone = header.clone();
 
             codon.push('\n');
             h_clone.push('\n');
 
-            vec![h_clone, codon]
-        })
-        .flatten()
-    );
+            ret[seq_length - *i] = vec![h_clone, codon]
+        });
+           
+    String::from_iter(ret.iter().cloned().flatten())
 
-    file
 }
 
 #[pymodule]
